@@ -43,7 +43,7 @@ type Container struct {
 }
 
 // Remove removes the container
-func (c *Container) Remove(options dockerTypes.ContainerRemoveOptions) error {
+func (c *Container) Remove(options container.RemoveOptions) error {
 	c.Log.Warn(fmt.Sprintf("removing container %s", c.Name))
 	if err := c.Client.ContainerRemove(context.Background(), c.ID, options); err != nil {
 		if strings.Contains(err.Error(), "Stop the container before attempting removal or force remove") {
@@ -62,7 +62,7 @@ func (c *Container) Remove(options dockerTypes.ContainerRemoveOptions) error {
 // Stop stops the container
 func (c *Container) Stop() error {
 	c.Log.Warn(fmt.Sprintf("stopping container %s", c.Name))
-	return c.Client.ContainerStop(context.Background(), c.ID, nil)
+	return c.Client.ContainerStop(context.Background(), c.ID, container.StopOptions{})
 }
 
 // Pause pauses the container
@@ -80,7 +80,7 @@ func (c *Container) Unpause() error {
 // Restart restarts the container
 func (c *Container) Restart() error {
 	c.Log.Warn(fmt.Sprintf("restarting container %s", c.Name))
-	return c.Client.ContainerRestart(context.Background(), c.ID, nil)
+	return c.Client.ContainerRestart(context.Background(), c.ID, container.StopOptions{})
 }
 
 // Attach attaches the container
